@@ -14,20 +14,25 @@
   DESTINATION="${PREFIX:-/usr/local/bin}/toast"
 
   # Which version to download
-  RELEASE="v${VERSION:-0.47.0}"
+  RELEASE="v${VERSION:-0.47.2}"
 
   # Determine which binary to download.
   FILENAME=''
   if uname -a | grep -qi 'x86_64.*GNU/Linux'; then
     echo 'x86-64 GNU Linux detected.'
     FILENAME=toast-x86_64-unknown-linux-gnu
-  elif uname -a | grep -qi 'x86_64 Linux'; then
+  elif uname -a | grep -qi 'x86_64.*Linux'; then
     echo 'x86-64 non-GNU Linux detected.'
     FILENAME=toast-x86_64-unknown-linux-musl
-  fi
-  if uname -a | grep -qi 'Darwin.*x86_64'; then
+  elif uname -a | grep -qi 'aarch64.*GNU/Linux'; then
+    echo 'AArch64 GNU Linux detected.'
+    FILENAME=toast-aarch64-unknown-linux-gnu
+  elif uname -a | grep -qi 'Darwin.*x86_64'; then
     echo 'x86-64 macOS detected.'
     FILENAME=toast-x86_64-apple-darwin
+  elif uname -a | grep -qi 'Darwin.*arm64'; then
+    echo 'AArch64 macOS detected.'
+    FILENAME=toast-aarch64-apple-darwin
   fi
 
   # Find a temporary location for the binary.
