@@ -6,7 +6,7 @@ use {
         fs::{copy, create_dir_all, rename, symlink_metadata, Metadata},
         io,
         io::Read,
-        path::{Path, PathBuf},
+        path::Path,
         process::{ChildStdin, Command, Stdio},
         string::ToString,
         sync::{
@@ -15,6 +15,7 @@ use {
         },
     },
     tempfile::tempdir,
+    typed_path::{TryAsRef, UnixPath, UnixPathBuf},
     walkdir::WalkDir,
 };
 
@@ -118,7 +119,7 @@ pub fn create_container(
     mount_paths: &[MappingPath],
     mount_readonly: bool,
     ports: &[String],
-    location: &Path,
+    location: &UnixPath,
     user: &str,
     command: &str,
     extra_args: &[String],
@@ -250,8 +251,8 @@ fn rename_or_copy_file_or_symlink(
 pub fn copy_from_container(
     docker_cli: &str,
     container: &str,
-    paths: &[PathBuf],
-    source_dir: &Path,
+    paths: &[UnixPathBuf],
+    source_dir: &UnixPath,
     destination_dir: &Path,
     interrupted: &Arc<AtomicBool>,
 ) -> Result<(), Failure> {
@@ -277,7 +278,12 @@ pub fn copy_from_container(
         // Figure out what needs to go where.
         let source = source_dir.join(path);
         let intermediate = temp_dir.path().join("data");
-        let destination = destination_dir.join(path);
+        let destination = destination_dir.join(path.try_as_ref().ok_or_else(|| {
+            Failure::User(
+                format!("Invalid path {}", path.to_string_lossy().code_str()),
+                None,
+            )
+        })?);
 
         // Get the path from the container.
         run_quiet(
@@ -453,7 +459,7 @@ pub fn spawn_shell(
     image: &str,
     source_dir: &Path,
     environment: &HashMap<String, String>,
-    location: &Path,
+    location: &UnixPath,
     mount_paths: &[MappingPath],
     mount_readonly: bool,
     ports: &[String],
@@ -500,7 +506,7 @@ pub fn spawn_shell(
 fn container_args(
     source_dir: &Path,
     environment: &HashMap<String, String>,
-    location: &Path,
+    location: &UnixPath,
     mount_paths: &[MappingPath],
     mount_readonly: bool,
     ports: &[String],
